@@ -26,7 +26,7 @@ echo "Version: $VERSION" >> debian/control
 echo "Installed-Size: "`du -c -k ${AUTO_DIR} | tail -1 | cut -f1` \
     >> debian/control
 echo "XB-Maemo-Icon-26:" >> debian/control
-uuencode -m pkg/maemo/dorian-48.png dorian.png | \
+uuencode -m pkg/maemo/icon-48/dorian.png dorian.png | \
     (read; cat) | grep -v '^====' | \
     sed 's/^/ /' >> debian/control
 
